@@ -31,7 +31,7 @@
 #include <tqvaluelist.h>
 
 // KDE includes
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 // Project includes
 
@@ -42,7 +42,7 @@ class KMFCheckInput;
 #define NUMDIGITS 4
 
 
-class KDE_EXPORT IPAddress {
+class TDE_EXPORT IPAddress {
 public:
 	IPAddress( int = 0, int = 0, int = 0, int = 0 );
 	~IPAddress();
