@@ -22,7 +22,7 @@
 
 #include "kmfgenericinterfaceicmp.h"
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 #include <tqcheckbox.h>
 
@@ -37,10 +37,10 @@
 namespace KMF {
 KMFGenericInterfaceIcmp::KMFGenericInterfaceIcmp( TQWidget *parent, const char *name, WFlags f )
 		: KMyFirewallGenericInterfaceIcmp( parent, name, f ) {
-connect( c_allow_ping, TQT_SIGNAL( toggled( bool ) ),
-	this, TQT_SLOT( slotEnablePingReplyToggled( bool ) ) );
-connect( c_limit_ping, TQT_SIGNAL( toggled( bool ) ),
-	this, TQT_SLOT( slotEnablePingReplyLimitToggled( bool ) ) );
+connect( c_allow_ping, TQ_SIGNAL( toggled( bool ) ),
+	this, TQ_SLOT( slotEnablePingReplyToggled( bool ) ) );
+connect( c_limit_ping, TQ_SIGNAL( toggled( bool ) ),
+	this, TQ_SLOT( slotEnablePingReplyLimitToggled( bool ) ) );
 }
 
 
