@@ -44,7 +44,7 @@ class KMFTarget;
  * @author Christian Hubinger <chubinger@irrsinnig.org>
  */
 class KMFInstallerPlugin : public KMFPlugin {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	/**
@@ -102,7 +102,7 @@ private:
 };
 
 class KMFInstallerPluginFactory : public KLibFactory {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFInstallerPluginFactory( TQObject *parent = 0, const char *name = 0 );
@@ -110,7 +110,7 @@ public:
 		delete s_instance;
 	};
 	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
-	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
+	                               const char* name = "TQObject",
 	                               const TQStringList &args = TQStringList() );
 private:
 	static TDEInstance* s_instance;
