@@ -18,13 +18,13 @@
 // TQt includes
 
 // KDE includes
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 // project includes
 namespace KMF {
 class KMFDoc;
 
-class KDE_EXPORT KMFDocumentInfo : public KMyFirewallDocumentInfo {
+class TDE_EXPORT KMFDocumentInfo : public KMyFirewallDocumentInfo {
 	TQ_OBJECT
   
 
