@@ -17,7 +17,7 @@
 #define KMFIPTDOCOPTIONS_H
 
 #include <tqwidget.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include "kmyfirewalliptdocoptions.h"
 
 /**
@@ -29,8 +29,8 @@ class TQString;
 namespace KMF {
 class KMFIPTDoc;
 
-class KDE_EXPORT KMFIPTDocOptions : public KMyFirewallIPTDocOptions {
-	Q_OBJECT
+class TDE_EXPORT KMFIPTDocOptions : public KMyFirewallIPTDocOptions {
+	TQ_OBJECT
   
 public:
 	KMFIPTDocOptions( TQWidget *parent = 0, const char *name = 0 );
