@@ -14,7 +14,7 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001-2004
 
 #include "kmflistview.h"
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 #include <tqptrlist.h>
 #include <kiconloader.h>
@@ -41,8 +41,8 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001-2004
 namespace KMF {
 KMFListView::KMFListView( TQWidget *parent, const char *name ) : TDEListView( parent, name ) {
 	loadIcons();
-	connect( this, TQT_SIGNAL( sigLoadNode( NetfilterObject* ) ),
-	         this, TQT_SLOT( slotLoadNode( NetfilterObject* ) ) );
+	connect( this, TQ_SIGNAL( sigLoadNode( NetfilterObject* ) ),
+	         this, TQ_SLOT( slotLoadNode( NetfilterObject* ) ) );
 	cast_error = i18n( "ERROR: Wrong ListViewItem Class used!\nThis is no KMFListViewItem" );
 	setSorting(0,true);
 	m_show_desc = true;
