@@ -13,7 +13,7 @@
 
 #include "kmfnethostpropertieswidget.h"
 
-// QT includes
+// TQt includes
 #include <tqlistview.h>
 #include <tqcheckbox.h>
 #include <tqspinbox.h>
@@ -49,23 +49,23 @@ KMFNetHostPropertiesWidget::KMFNetHostPropertiesWidget ( TQWidget* parent, const
 		
 	m_address_widget = new KMFIPv4AddressWidget( m_frameAddress, "m_address_widget" );
 	
-	connect( m_address_widget, TQT_SIGNAL( sigAddressChanged( int, int, int, int ) ),
-		this,TQT_SLOT( slotAddressChanged( int, int, int, int ) ) );
+	connect( m_address_widget, TQ_SIGNAL( sigAddressChanged( int, int, int, int ) ),
+		this,TQ_SLOT( slotAddressChanged( int, int, int, int ) ) );
 	
-	connect( m_cb_host_limit, TQT_SIGNAL( toggled( bool ) ), 
-		this, TQT_SLOT( slotHostLimitToggled( bool ) ) );	
+	connect( m_cb_host_limit, TQ_SIGNAL( toggled( bool ) ), 
+		this, TQ_SLOT( slotHostLimitToggled( bool ) ) );	
 	
-	connect( m_sb_host_rate, TQT_SIGNAL( valueChanged( int ) ),
-		this, TQT_SLOT( slotHostLimitValueChanged( int ) ) );
+	connect( m_sb_host_rate, TQ_SIGNAL( valueChanged( int ) ),
+		this, TQ_SLOT( slotHostLimitValueChanged( int ) ) );
 	
-	connect( m_cb_limit_host_interval, TQT_SIGNAL( activated( int ) ),
-		this, TQT_SLOT( slotHostLimitScaleChanged( int ) ) );
+	connect( m_cb_limit_host_interval, TQ_SIGNAL( activated( int ) ),
+		this, TQ_SLOT( slotHostLimitScaleChanged( int ) ) );
 	
-	connect( m_cb_host_log, TQT_SIGNAL( toggled( bool ) ),
-		this, TQT_SLOT( slotHostLogToggled( bool ) ) );
+	connect( m_cb_host_log, TQ_SIGNAL( toggled( bool ) ),
+		this, TQ_SLOT( slotHostLogToggled( bool ) ) );
 
-	connect( m_host_desc, TQT_SIGNAL( textChanged() ),
-		this, TQT_SLOT( slotDescriptionChanged() ) );
+	connect( m_host_desc, TQ_SIGNAL( textChanged() ),
+		this, TQ_SLOT( slotDescriptionChanged() ) );
 	
     TQGridLayout *grid = new TQGridLayout( m_frameAddress, 1, 1 );
 	grid->addWidget( m_address_widget, 0, 0 );
@@ -94,13 +94,13 @@ void KMFNetHostPropertiesWidget::loadHost( KMFNetHost* host ) {
 	}
 	
 	if ( m_host ) {
-		disconnect( m_host, TQT_SIGNAL( destroyed() ),
-			this,TQT_SLOT( slotHostDeleted() ) );
+		disconnect( m_host, TQ_SIGNAL( destroyed() ),
+			this,TQ_SLOT( slotHostDeleted() ) );
 	}
 	
 	m_host = host;
-	connect( m_host, TQT_SIGNAL( destroyed() ),
-			this,TQT_SLOT( slotHostDeleted() ) );
+	connect( m_host, TQ_SIGNAL( destroyed() ),
+			this,TQ_SLOT( slotHostDeleted() ) );
 	blockAllSignals( true );
 	setEnabled( true );
 	m_address_widget->loadIPAddress( 
