@@ -13,7 +13,7 @@
 
 #include "kmfprotocolpropertieswidget.h"
 
-// QT includes
+// TQt includes
 #include <tqlistview.h>
 #include <tqcheckbox.h>
 #include <tqspinbox.h>
@@ -46,16 +46,16 @@ namespace KMF {
 KMFProtocolPropertiesWidget::KMFProtocolPropertiesWidget ( TQWidget* parent, const char* name, WFlags fl )
 		: KMyFirewallProtocolPropertiesWidget ( parent,name,fl ) {
 		
-	connect( m_cb_limit, TQT_SIGNAL( toggled( bool ) ),
-		this, TQT_SLOT( slotEnableProtocolLimit( bool ) ) );
+	connect( m_cb_limit, TQ_SIGNAL( toggled( bool ) ),
+		this, TQ_SLOT( slotEnableProtocolLimit( bool ) ) );
 				
-	connect( m_sb_limit_rate, TQT_SIGNAL( valueChanged( int ) ),
-		this, TQT_SLOT( slotSetProtocolLimitRate( int ) ) );
+	connect( m_sb_limit_rate, TQ_SIGNAL( valueChanged( int ) ),
+		this, TQ_SLOT( slotSetProtocolLimitRate( int ) ) );
 	
-	connect( m_cb_limit_interval, TQT_SIGNAL( highlighted( const TQString& ) ), 	this, TQT_SLOT( slotSetProtocolLimitInterval( const TQString& ) ) );
+	connect( m_cb_limit_interval, TQ_SIGNAL( highlighted( const TQString& ) ), 	this, TQ_SLOT( slotSetProtocolLimitInterval( const TQString& ) ) );
 
-	connect( m_cb_log, TQT_SIGNAL( toggled( bool ) ),
-		this, TQT_SLOT( slotEnableProtocolLogging( bool ) ) );
+	connect( m_cb_log, TQ_SIGNAL( toggled( bool ) ),
+		this, TQ_SLOT( slotEnableProtocolLogging( bool ) ) );
 	
 }
 
@@ -120,13 +120,13 @@ void KMFProtocolPropertiesWidget::loadProtocolUsage( KMFProtocolUsage* prot ) {
 	}
 	
 	if ( m_protocolUsage ) {
-		disconnect( m_protocolUsage, TQT_SIGNAL( destroyed() ),
-			this,TQT_SLOT( slotProtocolDeleted() ) );
+		disconnect( m_protocolUsage, TQ_SIGNAL( destroyed() ),
+			this,TQ_SLOT( slotProtocolDeleted() ) );
 	}
 	
 	m_protocolUsage = prot;
-	connect( m_protocolUsage, TQT_SIGNAL( destroyed() ),
-			this,TQT_SLOT( slotProtocolDeleted() ) );
+	connect( m_protocolUsage, TQ_SIGNAL( destroyed() ),
+			this,TQ_SLOT( slotProtocolDeleted() ) );
 	setEnabled( true );
 	
 	blockAllSignals( true );
