@@ -19,13 +19,15 @@
 #include <tqstring.h>
 #include <tqguardedptr.h>
 #include <tqpoint.h>
+#include <tdemacros.h>
+
 class TQListViewItem;
 
 namespace KMF {
 class KMFNetwork;
 class KMFTarget;
 
-class KMFSelectActiveTarget : public KMyFirewallSelectActiveTarget
+class TDE_EXPORT KMFSelectActiveTarget : public KMyFirewallSelectActiveTarget
 {
 		TQ_OBJECT
   
