@@ -12,7 +12,7 @@
 
 #include "kmfselectinterface.h"
 
-//  QT includes
+//  TQt includes
 #include <tqlabel.h>
 #include <tqcheckbox.h>
 #include <tqcolor.h>
@@ -51,10 +51,10 @@ KMFSelectInterface::KMFSelectInterface( TQWidget *parent, const char *name, bool
 		
 		
 		
-	connect( m_cob_interface, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( slotInterfaceChanged( int ) ) );
-	connect( m_cmd_ok, TQT_SIGNAL( clicked() ) , this, TQT_SLOT( accept() ) );	
-	connect( m_cmd_help, TQT_SIGNAL( clicked() ) , this, TQT_SLOT( help() ) );
-	connect( b_close, TQT_SIGNAL( clicked() ) , this, TQT_SLOT( reject() ) );
+	connect( m_cob_interface, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotInterfaceChanged( int ) ) );
+	connect( m_cmd_ok, TQ_SIGNAL( clicked() ) , this, TQ_SLOT( accept() ) );	
+	connect( m_cmd_help, TQ_SIGNAL( clicked() ) , this, TQ_SLOT( help() ) );
+	connect( b_close, TQ_SIGNAL( clicked() ) , this, TQ_SLOT( reject() ) );
 	
 	adjustSize();
 }
