@@ -34,12 +34,12 @@
 #include "kmftemplatechooser.h"
 namespace KMF {
 KMFTemplateChooser::KMFTemplateChooser(TQWidget* parent, const char* name, bool modal, WFlags fl) : KMyFirewallTemplateChooser(parent,name, modal,fl) {
-	connect( lb_templates, TQT_SIGNAL( highlighted ( int ) ), 
-		this, TQT_SLOT( slotNewTemplateSelected( int ) ) );
-	connect( lb_templates, TQT_SIGNAL( doubleClicked( TQListBoxItem* ) ), 
-		this, TQT_SLOT( slotNewTemplateSelected( TQListBoxItem* ) ) );
-	connect( b_help, TQT_SIGNAL( clicked() ),
-		this, TQT_SLOT( slotHelp() ) );
+	connect( lb_templates, TQ_SIGNAL( highlighted ( int ) ), 
+		this, TQ_SLOT( slotNewTemplateSelected( int ) ) );
+	connect( lb_templates, TQ_SIGNAL( doubleClicked( TQListBoxItem* ) ), 
+		this, TQ_SLOT( slotNewTemplateSelected( TQListBoxItem* ) ) );
+	connect( b_help, TQ_SIGNAL( clicked() ),
+		this, TQ_SLOT( slotHelp() ) );
 
 	parseTemplates();
 	b_accept->setEnabled( false );
