@@ -21,14 +21,14 @@
 #include <tqptrlist.h>
 
 // KDE includes
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 // project includes
 
 
 class TQListBoxItem;
 namespace KMF {
-class KDE_EXPORT KMFTemplateChooser : public KMyFirewallTemplateChooser {
+class TDE_EXPORT KMFTemplateChooser : public KMyFirewallTemplateChooser {
 	TQ_OBJECT
   
 
