@@ -28,7 +28,7 @@ class IPTRule;
 
 
 class KMFRuleEditTargetMark : public KMyFirewallRuleEditorTargetMark {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleEditTargetMark( TQWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
